==> master_f_2.4.1.zip: arome/app/src/main/java/com/hh/arome/http/ApiService.java <==
package com.hh.arome.http;

import com.common.lib_base.common.http.bean.BaseBean;
import com.hh.arome.BuildConfig;
import com.hh.arome.bean.AlipayUserInfoResultBean;
import com.hh.arome.bean.DeviceConfigResultBean;
import com.hh.arome.bean.SimpleResultBean;
import com.hh.arome.bean.ampe.AmpeConfigResultBean;

import io.reactivex.Observable;
import okhttp3.RequestBody;
import retrofit2.http.Body;
import retrofit2.http.POST;
import retrofit2.http.Url;

import static com.hh.arome.BuildConfig.BASE_API_URL;
import static com.hh.arome.common.Constants.Url.API_CONFIG_QUERY;
import static com.hh.arome.common.Constants.Url.API_CONFIG_UPDATE;
import static com.hh.arome.common.Constants.Url.API_LOGCAT_ADD;

public interface ApiService {


    // 获取设备在线配置
//    @POST("hanghui/outapi/api/v1/iot/device/config/sn/config")
    @POST(BASE_API_URL + API_CONFIG_QUERY)
    Observable<BaseBean<DeviceConfigResultBean>> requestDeviceConfig(@Body RequestBody body);

    // 设备-修改配置信息
    @POST(BASE_API_URL + API_CONFIG_UPDATE)
    Observable<BaseBean<SimpleResultBean>> requestDeviceConfigUpdate(@Body RequestBody body);


    // 动态修改baseurl
    // 业务app心跳
    @POST
    Observable<BaseBean<SimpleResultBean>> requestHeartBeat(@Url String url, @Body RequestBody login);

    // 在线日志
    @POST(BASE_API_URL + API_LOGCAT_ADD)
    Observable<BaseBean<SimpleResultBean>> requestLogcatAdd(@Body RequestBody body);


    // 获取支付宝用户三要素
    @POST
    Observable<BaseBean<AlipayUserInfoResultBean>> requestAlipayUserInfo(@Url String url, @Body RequestBody login);


}

==> master_f_2_8_2.zip: arome/app/src/main/java/com/hh/arome/http/ApiService.java <==
package com.hh.arome.http;

import com.common.lib_base.common.http.bean.BaseBean;
import com.hh.arome.BuildConfig;
import com.hh.arome.bean.AlipayUserInfoResultBean;
import com.hh.arome.bean.DeviceConfigResultBean;
import com.hh.arome.bean.SimpleResultBean;
import com.hh.arome.bean.ThreeElementsBean;
import com.hh.arome.bean.ampe.AmpeConfigResultBean;

import io.reactivex.Observable;
import okhttp3.RequestBody;
import retrofit2.http.Body;
import retrofit2.http.POST;
import retrofit2.http.Url;

import static com.hh.arome.BuildConfig.BASE_API_URL;
import static com.hh.arome.common.Constants.Url.API_CONFIG_QUERY;
import static com.hh.arome.common.Constants.Url.API_CONFIG_UPDATE;
import static com.hh.arome.common.Constants.Url.API_LOGCAT_ADD;

public interface ApiService {


    // 获取设备在线配置
//    @POST("hanghui/outapi/api/v1/iot/device/config/sn/config")
    @POST(BASE_API_URL + API_CONFIG_QUERY)
    Observable<BaseBean<DeviceConfigResultBean>> requestDeviceConfig(@Body RequestBody body);

    // 设备-修改配置信息
    @POST(BASE_API_URL + API_CONFIG_UPDATE)
    Observable<BaseBean<SimpleResultBean>> requestDeviceConfigUpdate(@Body RequestBody body);


    // 动态修改baseurl
    // 业务app心跳
    @POST
    Observable<BaseBean<SimpleResultBean>> requestHeartBeat(@Url String url, @Body RequestBody login);

    // 在线日志
//    @POST(BASE_API_URL + API_LOGCAT_ADD)
    @POST
    Observable<BaseBean<SimpleResultBean>> requestLogcatAdd(@Url String url,@Body RequestBody body);

    //公安网换取三要素
//    @POST(BASE_API_URL + API_LOGCAT_ADD)
    @POST
    Observable<BaseBean<ThreeElementsBean>> requestThreeElements(@Url String url, @Body RequestBody body);
    // 获取支付宝用户三要素
    @POST
    Observable<BaseBean<AlipayUserInfoResultBean>> requestAlipayUserInfo(@Url String url, @Body RequestBody login);


}
